@@ -1,12 +1,14 @@
 package App::ScreensaverUtils;
 
-our $DATE = '2019-09-03'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2019-09-04'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
+use Screensaver::Any ();
+
 our %SPEC;
 
 $SPEC{prevent_screensaver_activated_while} = {
@@ -71,6 +73,39 @@ sub prevent_screensaver_activated_until_interrupted {
     [200, "Exit code is $exit", "", {"cmdline.exit_code"=>$exit}];
 }
 
+$SPEC{get_screensaver_info} = {
+    v => 1.1,
+    summary => 'Get screensaver information (detected screensaver, is_active, is_enabled, timeout)',
+    args => {
+        %Screensaver::Any::arg_screensaver,
+    },
+};
+sub get_screensaver_info {
+    my %args = @_;
+
+    my %res;
+
+    {
+        if ($args{screensaver}) {
+            $res{screensaver} = $args{screensaver};
+        } else {
+            last unless $res{screensaver} = Screensaver::Any::detect_screensaver();
+        }
+
+        my $res = Screensaver::Any::screensaver_is_enabled(%args);
+        $res{is_enabled} = $res->[0] == 200 ? $res->[2] : undef;
+
+        $res = Screensaver::Any::screensaver_is_active(%args);
+        $res{is_active} = $res->[0] == 200 ? $res->[2] : undef;
+
+        $res = Screensaver::Any::get_screensaver_timeout(%args);
+        $res{timeout} = $res->[0] == 200 ? $res->[2] : undef;
+    }
+
+    [200, "OK", \%res];
+
+}
+
 1;
 # ABSTRACT: CLI utilities related to screensaver
 
@@ -86,7 +121,7 @@ App::ScreensaverUtils - CLI utilities related to screensaver
 
 =head1 VERSION
 
-This document describes version 0.005 of App::ScreensaverUtils (from Perl distribution App-ScreensaverUtils), released on 2019-09-03.
+This document describes version 0.006 of App::ScreensaverUtils (from Perl distribution App-ScreensaverUtils), released on 2019-09-04.
 
 =head1 DESCRIPTION
 
@@ -104,6 +139,8 @@ This distribution contains the following CLI utilities related to screensaver:
 
 =item * L<enable-screensaver>
 
+=item * L<get-screensaver-info>
+
 =item * L<get-screensaver-timeout>
 
 =item * L<noss>
@@ -118,6 +155,8 @@ This distribution contains the following CLI utilities related to screensaver:
 
 =item * L<screensaver-is-active>
 
+=item * L<screensaver-is-enabled>
+
 =item * L<set-screensaver-timeout>
 
 =back
@@ -125,6 +164,41 @@ This distribution contains the following CLI utilities related to screensaver:
 =head1 FUNCTIONS
 
 
+=head2 get_screensaver_info
+
+Usage:
+
+ get_screensaver_info(%args) -> [status, msg, payload, meta]
+
+Get screensaver information (detected screensaver, is_active, is_enabled, timeout).
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<screensaver> => I<str>
+
+Explicitly set screensaver program to use.
+
+The default, when left undef, is to detect what screensaver is running,
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 prevent_screensaver_activated_until_interrupted
 
 Usage:
